@@ -48,11 +48,11 @@ def split_filepath(url: str) -> 'tuple[str, str]':
 
 def get_logpath(tz: str = 'America/Sao_Paulo') -> str:
     """
-    This return the current date formatted for logging directories.
-    e.g.: my_container_fullpath = 'ingestion/dir/subdir' \ \n
-    \+ f"{get_container_logpath()}" \n
-    print(my_container_fullpath) will return:
-    * 'ingestion/dir/subdir/THIS_YEAR/THIS_MONTH/THIS_DAY'.\n
+    Returns the current date formatted for logging directories.
+    \nExample:\n
+    * container_fullpath = 'my_container/subdir' + get_logpath() \n
+    The print(container_fullpath) will return:
+    * 'my_container/subdir/<THIS_YEAR>/<THIS_MONTH>/<THIS_DAY>'.\n
     
     :param str: timezone\n
     Default timezone is 'America/Sao_Paulo'.
